#[repr(C)]pub struct Descriptor {
pub addr: u64,
pub len: u32,
pub flags: u16,
pub next: u16,
}Expand description
Descriptor structure
This structure represents a descriptor in the descriptor table. It contains the address, length, flags, and next pointer. This structure is located in the physical memory directly.
Fields
addr: u64len: u32flags: u16next: u16